@@ -6,8 +6,6 @@ sys.path.append(os.path.dirname(__file__))  # let code under test load stubs
 from device_test import DeviceTestCase
 
 class TestRadioStats(DeviceTestCase):
-    def setUp(self):
-        super().setUp()
 
     def test_ligowave_ligowave_LigoWave_AP_1_1_1_01(self):
         obj = self.run_data("ligowave.ligowave.LigoWave AP.1.1.1.01")
@@ -122,7 +120,6 @@ class TestRadioStats(DeviceTestCase):
                                                                                          'ssid': 'Osage '
                                                                                                  'AP '
                                                                                                  'North'}],
-                                                              'speed': '0',
                                                               'type': 1}],
                                 'manufacturer': 'LigoWave',
                                 'model': 'LigoWave AP',
@@ -184,10 +181,12 @@ class TestRadioStats(DeviceTestCase):
                                          'poller_hash': 'ABk7Eydc',
                                          'status': 'ELEMENT_STATUS_ONLINE'}]
         }
-        id_field = 'mac_address' if not obj.stations else ('mac_address' if hasattr(obj.stations[0], 'mac_address') else ('imsi' if hasattr(obj.stations[0], 'imsi') else 'serial'))
+        id_field = 'mac_address' if not obj.stations else ('mac_address' if hasattr(obj.stations[0], 'mac_address') and getattr(obj.stations[0], 'mac_address') else ('imsi' if hasattr(obj.stations[0], 'imsi') else 'serial'))
         cur_info = {x: getattr(obj, x, None) for (x, data_type) in self.apdd.get_metric_fields('info', 'ap', obj.model) + [('vendor', 'str'), ('model', 'str'), ('sw_version', 'str')]}
+        if 'rf_freq' in cur_info and cur_info.get('rf_freq') and (cur_info['rf_freq'] <= 0 or int.bit_length(cur_info['rf_freq']) >= 32):
+            cur_info.pop('rf_freq')
         cur_stats = {x: getattr(obj, x, None) for (x, data_type) in self.apdd.get_metric_fields('stats', 'ap', obj.model)}
-        cur_sta_stats = {getattr(sta, id_field): {x: getattr(sta, x, None) for (x, data_type) in self.apdd.get_metric_fields('stats', 'cpe', obj.model) + [(id_field, 'str'), ('ip_address', 'str'), ('name', 'str'), ('dev_macs', 'str')]} for sta in obj.stations}
+        cur_sta_stats = {getattr(sta, id_field): {x: getattr(sta, x, None) for (x, data_type) in sorted(self.apdd.get_metric_fields('stats', 'cpe', obj.model)) + [(id_field, 'str'), ('ip_address', 'str'), ('name', 'str'), ('dev_macs', 'str')]} for sta in sorted(obj.stations)}
         cur_ne_msg = getattr(obj, 'network_element_update_msg', None)
         cur_ne_msg = cur_ne_msg.pb if cur_ne_msg else None
         self.assertEqual(cur_info, exp_info)
@@ -236,10 +235,12 @@ class TestRadioStats(DeviceTestCase):
                                 'system_mac_address': '00:19:3b:04:70:6a',
                                 'uptime': '42317914'}
         }
-        id_field = 'mac_address' if not obj.stations else ('mac_address' if hasattr(obj.stations[0], 'mac_address') else ('imsi' if hasattr(obj.stations[0], 'imsi') else 'serial'))
+        id_field = 'mac_address' if not obj.stations else ('mac_address' if hasattr(obj.stations[0], 'mac_address') and getattr(obj.stations[0], 'mac_address') else ('imsi' if hasattr(obj.stations[0], 'imsi') else 'serial'))
         cur_info = {x: getattr(obj, x, None) for (x, data_type) in self.apdd.get_metric_fields('info', 'ap', obj.model) + [('vendor', 'str'), ('model', 'str'), ('sw_version', 'str')]}
+        if 'rf_freq' in cur_info and cur_info.get('rf_freq') and (cur_info['rf_freq'] <= 0 or int.bit_length(cur_info['rf_freq']) >= 32):
+            cur_info.pop('rf_freq')
         cur_stats = {x: getattr(obj, x, None) for (x, data_type) in self.apdd.get_metric_fields('stats', 'ap', obj.model)}
-        cur_sta_stats = {getattr(sta, id_field): {x: getattr(sta, x, None) for (x, data_type) in self.apdd.get_metric_fields('stats', 'cpe', obj.model) + [(id_field, 'str'), ('ip_address', 'str'), ('name', 'str'), ('dev_macs', 'str')]} for sta in obj.stations}
+        cur_sta_stats = {getattr(sta, id_field): {x: getattr(sta, x, None) for (x, data_type) in sorted(self.apdd.get_metric_fields('stats', 'cpe', obj.model)) + [(id_field, 'str'), ('ip_address', 'str'), ('name', 'str'), ('dev_macs', 'str')]} for sta in sorted(obj.stations)}
         cur_ne_msg = getattr(obj, 'network_element_update_msg', None)
         cur_ne_msg = cur_ne_msg.pb if cur_ne_msg else None
         self.assertEqual(cur_info, exp_info)
@@ -324,7 +325,6 @@ class TestRadioStats(DeviceTestCase):
                                                                                         'tx_power': 24}],
                                                               'sectors': [       {       'mode': 'AP',
                                                                                          'ssid': 'Bluff/KOA'}],
-                                                              'speed': '0',
                                                               'type': 1}],
                                 'manufacturer': 'LigoWave',
                                 'model': 'LigoWave AP',
@@ -349,10 +349,12 @@ class TestRadioStats(DeviceTestCase):
                                          'poller_hash': 'ABk7CoDx',
                                          'status': 'ELEMENT_STATUS_ONLINE'}]
         }
-        id_field = 'mac_address' if not obj.stations else ('mac_address' if hasattr(obj.stations[0], 'mac_address') else ('imsi' if hasattr(obj.stations[0], 'imsi') else 'serial'))
+        id_field = 'mac_address' if not obj.stations else ('mac_address' if hasattr(obj.stations[0], 'mac_address') and getattr(obj.stations[0], 'mac_address') else ('imsi' if hasattr(obj.stations[0], 'imsi') else 'serial'))
         cur_info = {x: getattr(obj, x, None) for (x, data_type) in self.apdd.get_metric_fields('info', 'ap', obj.model) + [('vendor', 'str'), ('model', 'str'), ('sw_version', 'str')]}
+        if 'rf_freq' in cur_info and cur_info.get('rf_freq') and (cur_info['rf_freq'] <= 0 or int.bit_length(cur_info['rf_freq']) >= 32):
+            cur_info.pop('rf_freq')
         cur_stats = {x: getattr(obj, x, None) for (x, data_type) in self.apdd.get_metric_fields('stats', 'ap', obj.model)}
-        cur_sta_stats = {getattr(sta, id_field): {x: getattr(sta, x, None) for (x, data_type) in self.apdd.get_metric_fields('stats', 'cpe', obj.model) + [(id_field, 'str'), ('ip_address', 'str'), ('name', 'str'), ('dev_macs', 'str')]} for sta in obj.stations}
+        cur_sta_stats = {getattr(sta, id_field): {x: getattr(sta, x, None) for (x, data_type) in sorted(self.apdd.get_metric_fields('stats', 'cpe', obj.model)) + [(id_field, 'str'), ('ip_address', 'str'), ('name', 'str'), ('dev_macs', 'str')]} for sta in sorted(obj.stations)}
         cur_ne_msg = getattr(obj, 'network_element_update_msg', None)
         cur_ne_msg = cur_ne_msg.pb if cur_ne_msg else None
         self.assertEqual(cur_info, exp_info)
